@@ -5,4 +5,5 @@ __all__ = ['topic', 'trace_elimination', 'music_score_recognition', 'speech_reco
            'idphoto_deep_beauty_to_b', 'gpu_accelerate', 'original_background_crop', 'title_detector', 'skin_quality',
            'wedding_photo_classic', 'image_handle_classic', 'face_info_classic', 'doc_correct',
            'watermark_removal_video', 'silent_reading_context_detect', 'check_photo_classic',
-           'double_picture_stitching', 'single_human_editor']
+           'double_picture_stitching', 'single_human_editor', 'human_plus_classic', 'extract_face_feature',
+           'match_face_feature']
